@@ -37,11 +37,17 @@
 #'
 #' @param model Statistical Model.
 #' @param ... Arguments passed to or from other methods. Non-documented
-#'   arguments are `digits`, `p_digits`, `ci_digits` and
-#'   `footer_digits` to set the number of digits for the output.
-#'   `group` can also be passed to the `print()` method. See details
-#'   in [print.parameters_model()] and 'Examples' in
-#'   [model_parameters.default()].
+#'   arguments are `digits`, `p_digits`, `ci_digits` and `footer_digits` to set
+#'   the number of digits for the output. If `s_value = TRUE`, the p-value will
+#'   be replaced by the S-value in the output (cf. _Rafi and Greenland 2020_).
+#'   `pd` adds an additional column with the _probability of direction_ (see
+#'   [bayestestR::p_direction()] for details). `groups` can be used to group
+#'   coefficients. It will be passed to the print-method, or can directly be used
+#'   in `print()`, see documentation in [print.parameters_model()]. Furthermore,
+#'   see 'Examples' in [model_parameters.default()]. For developers, whose
+#'   interest mainly is to get a "tidy" data frame of model summaries, it is
+#'   recommended to set `pretty_names = FALSE` to speed up computation of the
+#'   summary table.
 #'
 #' @seealso [insight::standardize_names()] to
 #'   rename columns into a consistent, standardized naming scheme.
@@ -285,6 +291,10 @@
 #'   - Neter, J., Wasserman, W., & Kutner, M. H. (1989). Applied linear
 #'   regression models.
 #'
+#'   - Rafi Z, Greenland S. Semantic and cognitive tools to aid statistical
+#'   science: replace confidence and significance by compatibility and surprise.
+#'   BMC Medical Research Methodology (2020) 20:244.
+
 #' @return A data frame of indices related to the model's parameters.
 #' @export
 model_parameters <- function(model, ...) {
@@ -305,6 +315,8 @@ model_parameters <- function(model, ...) {
 
 # Options -------------------------------------
 
+# Add new options to the docs in "print.parameters_model"
+
 # getOption("parameters_summary"): show model summary
 # getOption("parameters_mixed_summary"): show model summary for mixed models
 # getOption("parameters_cimethod"): show message about CI approximation
@@ -406,29 +418,25 @@ parameters <- model_parameters
 #'
 #' @inheritSection model_parameters Confidence intervals and approximation of degrees of freedom
 #'
-#' @examples
+#' @examplesIf require("boot", quietly = TRUE) && require("sandwich") && require("clubSandwich") && require("brglm2")
 #' library(parameters)
 #' model <- lm(mpg ~ wt + cyl, data = mtcars)
 #'
 #' model_parameters(model)
 #'
 #' # bootstrapped parameters
-#' if (require("boot", quietly = TRUE)) {
-#'   model_parameters(model, bootstrap = TRUE)
-#' }
+#' model_parameters(model, bootstrap = TRUE)
 #'
 #' # standardized parameters
 #' model_parameters(model, standardize = "refit")
 #'
 #' # robust, heteroskedasticity-consistent standard errors
-#' if (require("sandwich") && require("clubSandwich")) {
-#'   model_parameters(model, vcov = "HC3")
+#' model_parameters(model, vcov = "HC3")
 #'
-#'   model_parameters(model,
-#'     vcov = "vcovCL",
-#'     vcov_args = list(cluster = mtcars$cyl)
-#'   )
-#' }
+#' model_parameters(model,
+#'   vcov = "vcovCL",
+#'   vcov_args = list(cluster = mtcars$cyl)
+#' )
 #'
 #' # different p-value style in output
 #' model_parameters(model, p_digits = 5)
@@ -440,6 +448,15 @@ parameters <- model_parameters
 #'
 #' # show odds ratio / exponentiated coefficients
 #' model_parameters(model, exponentiate = TRUE)
+#'
+#' # bias-corrected logistic regression with penalized maximum likelihood
+#' model <- glm(
+#'   vs ~ wt + cyl,
+#'   data = mtcars,
+#'   family = "binomial",
+#'   method = "brglmFit"
+#' )
+#' model_parameters(model)
 #' }
 #' @return A data frame of indices related to the model's parameters.
 #' @export
@@ -458,10 +475,10 @@ model_parameters.default <- function(model,
                                      vcov = NULL,
                                      vcov_args = NULL,
                                      ...) {
-  # sanity check for inputs
+  # validation check for inputs
   .is_model_valid(model)
 
-  # sanity check, warn if unsupported argument is used.
+  # validation check, warn if unsupported argument is used.
   # unsupported arguments will be removed from the argument list.
   dots <- .check_dots(
     dots = list(...),
@@ -472,26 +489,24 @@ model_parameters.default <- function(model,
 
   # extract model parameters table, as data frame
   out <- tryCatch(
-    {
-      .model_parameters_generic(
-        model = model,
-        ci = ci,
-        ci_method = ci_method,
-        bootstrap = bootstrap,
-        iterations = iterations,
-        merge_by = "Parameter",
-        standardize = standardize,
-        exponentiate = exponentiate,
-        p_adjust = p_adjust,
-        summary = summary,
-        keep_parameters = keep,
-        drop_parameters = drop,
-        vcov = vcov,
-        vcov_args = vcov_args,
-        verbose = verbose,
-        ...
-      )
-    },
+    .model_parameters_generic(
+      model = model,
+      ci = ci,
+      ci_method = ci_method,
+      bootstrap = bootstrap,
+      iterations = iterations,
+      merge_by = "Parameter",
+      standardize = standardize,
+      exponentiate = exponentiate,
+      p_adjust = p_adjust,
+      summary = summary,
+      keep_parameters = keep,
+      drop_parameters = drop,
+      vcov = vcov,
+      vcov_args = vcov_args,
+      verbose = verbose,
+      ...
+    ),
     error = function(e) {
       fail <- NA
       attr(fail, "error") <- gsub("  ", " ", gsub("\\n", "", e$message), fixed = TRUE)
@@ -559,14 +574,14 @@ model_parameters.default <- function(model,
       ci_method <- "quantile"
     }
 
-    args <- list(
+    fun_args <- list(
       model,
       iterations = iterations,
       ci = ci,
       ci_method = ci_method
     )
-    args <- c(args, dots)
-    params <- do.call("bootstrap_parameters", args)
+    fun_args <- c(fun_args, dots)
+    params <- do.call("bootstrap_parameters", fun_args)
 
     # Processing, non-bootstrapped parameters
   } else {
@@ -575,7 +590,7 @@ model_parameters.default <- function(model,
       ci_method <- "wald"
     }
 
-    args <- list(
+    fun_args <- list(
       model,
       ci = ci,
       component = component,
@@ -590,8 +605,8 @@ model_parameters.default <- function(model,
       vcov = vcov,
       vcov_args = vcov_args
     )
-    args <- c(args, dots)
-    params <- do.call(".extract_parameters_generic", args)
+    fun_args <- c(fun_args, dots)
+    params <- do.call(".extract_parameters_generic", fun_args)
   }
 
 
@@ -639,6 +654,8 @@ model_parameters.glm <- function(model,
                                  exponentiate = FALSE,
                                  p_adjust = NULL,
                                  summary = getOption("parameters_summary", FALSE),
+                                 keep = NULL,
+                                 drop = NULL,
                                  vcov = NULL,
                                  vcov_args = NULL,
                                  verbose = TRUE,
@@ -647,7 +664,13 @@ model_parameters.glm <- function(model,
 
   # set default
   if (is.null(ci_method)) {
-    ci_method <- ifelse(isTRUE(bootstrap), "quantile", "profile")
+    if (isTRUE(bootstrap)) {
+      ci_method <- "quantile"
+    } else if (!is.null(vcov) || !is.null(vcov_args)) {
+      ci_method <- "wald"
+    } else {
+      ci_method <- "profile"
+    }
   }
 
   # profiled CIs may take a long time to compute, so we warn the user about it
@@ -658,7 +681,15 @@ model_parameters.glm <- function(model,
     )
   }
 
-  args <- list(
+  # tell user that profiled CIs don't respect vcov-args
+  if (identical(ci_method, "profile") && (!is.null(vcov) || !is.null(vcov_args)) && isTRUE(verbose)) {
+    insight::format_alert(
+      "When `ci_method=\"profile\"`, `vcov` only modifies standard errors, test-statistic and p-values, but not confidence intervals.", # nolint
+      "Use `ci_method=\"wald\"` to return confidence intervals based on robust standard errors."
+    )
+  }
+
+  fun_args <- list(
     model = model,
     ci = ci,
     ci_method = ci_method,
@@ -669,11 +700,14 @@ model_parameters.glm <- function(model,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
     summary = summary,
+    keep_parameters = keep,
+    drop_parameters = drop,
     vcov = vcov,
-    vcov_args = vcov_args
+    vcov_args = vcov_args,
+    verbose = verbose
   )
-  args <- c(args, dots)
-  out <- do.call(".model_parameters_generic", args)
+  fun_args <- c(fun_args, dots)
+  out <- do.call(".model_parameters_generic", fun_args)
 
   attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
