@@ -8,13 +8,14 @@ format.parameters_model <- function(x,
                                     split_components = TRUE,
                                     select = NULL,
                                     digits = 2,
-                                    ci_digits = 2,
+                                    ci_digits = digits,
                                     p_digits = 3,
                                     ci_width = NULL,
                                     ci_brackets = NULL,
                                     zap_small = FALSE,
                                     format = NULL,
                                     groups = NULL,
+                                    include_reference = FALSE,
                                     ...) {
   # save attributes
   coef_name <- attributes(x)$coefficient_name
@@ -74,6 +75,14 @@ format.parameters_model <- function(x,
     x$Response <- NULL
   }
 
+  # remove component for nestedLogit
+  if (!is.null(m_class) && any(m_class == "nestedLogit")) {
+    x$Component <- NULL
+    if (insight::n_unique(x$Response) == 1) {
+      x$Response <- NULL
+    }
+  }
+
   # remove type for comparisons()
   if (!is.null(m_class) && any(m_class == "comparisons")) {
     x$Type <- NULL
@@ -98,24 +107,8 @@ format.parameters_model <- function(x,
   # check if we have mixed models with random variance parameters
   # in such cases, we don't need the group-column, but we rather
   # merge it with the parameter column
-  if (isTRUE(random_variances) && !is.null(x$Group) && !is.null(x$Effects)) {
-    ran_pars <- which(x$Effects == "random")
-    stddevs <- startsWith(x$Parameter[ran_pars], "SD (")
-    x$Parameter[ran_pars[stddevs]] <- paste0(
-      gsub("(.*)\\)", "\\1", x$Parameter[ran_pars[stddevs]]),
-      ": ",
-      x$Group[ran_pars[stddevs]],
-      ")"
-    )
-    corrs <- startsWith(x$Parameter[ran_pars], "Cor (")
-    x$Parameter[ran_pars[corrs]] <- paste0(
-      gsub("(.*)\\)", "\\1", x$Parameter[ran_pars[corrs]]),
-      ": ",
-      x$Group[ran_pars[corrs]],
-      ")"
-    )
-    x$Parameter[x$Parameter == "SD (Observations: Residual)"] <- "SD (Residual)"
-    x$Group <- NULL
+  if (isTRUE(random_variances)) {
+    x <- .format_ranef_parameters(x)
   }
 
   # group parameters - this function find those parameters that should be
@@ -159,6 +152,7 @@ format.parameters_model <- function(x,
       ci_width = ci_width,
       ci_brackets = ci_brackets,
       zap_small = zap_small,
+      include_reference = include_reference,
       ...
     )
   } else {
@@ -175,6 +169,7 @@ format.parameters_model <- function(x,
       format = format,
       coef_name = coef_name,
       zap_small = zap_small,
+      include_reference = include_reference,
       ...
     )
   }
@@ -194,16 +189,16 @@ format.parameters_model <- function(x,
   # to "split" the formatted table, because the glue-function needs the columns
   # without the parameters-column.
   if (!is.null(style)) {
-    if (!is.data.frame(formatted_table)) {
-      formatted_table[] <- lapply(
+    if (is.data.frame(formatted_table)) {
+      formatted_table <- .style_formatted_table(
         formatted_table,
-        .style_formatted_table,
         style = style,
         format = format
       )
     } else {
-      formatted_table <- .style_formatted_table(
+      formatted_table[] <- lapply(
         formatted_table,
+        .style_formatted_table,
         style = style,
         format = format
       )
@@ -251,7 +246,7 @@ format.compare_parameters <- function(x,
                                       split_components = TRUE,
                                       select = NULL,
                                       digits = 2,
-                                      ci_digits = 2,
+                                      ci_digits = digits,
                                       p_digits = 3,
                                       ci_width = NULL,
                                       ci_brackets = NULL,
@@ -295,12 +290,12 @@ format.compare_parameters <- function(x,
   ran_pars <- which(x$Effects == "random")
 
   # find all random effect groups
-  if (!is.null(x$Group)) {
-    ran_groups <- unique(insight::compact_character(x$Group))
-    ran_group_rows <- which(nchar(x$Group) > 0)
-  } else {
+  if (is.null(x$Group)) {
     ran_groups <- NULL
     ran_group_rows <- NULL
+  } else {
+    ran_groups <- unique(insight::compact_character(x$Group))
+    ran_group_rows <- which(nzchar(x$Group, keepNA = TRUE))
   }
 
   for (i in models) {
@@ -330,9 +325,12 @@ format.compare_parameters <- function(x,
       # find SD random parameters
       stddevs <- startsWith(out$Parameter[ran_pars_rows], "SD (")
       # check if we already fixed that name in a previous loop
-      fixed_name <- unlist(lapply(ran_groups, function(g) {
-        which(grepl(g, out$Parameter[ran_pars_rows[stddevs]], fixed = TRUE))
-      }))
+      fixed_name <- unlist(lapply(
+        ran_groups,
+        grep,
+        x = out$Parameter[ran_pars_rows[stddevs]],
+        fixed = TRUE
+      ))
       if (length(fixed_name)) {
         stddevs[fixed_name] <- FALSE
       }
@@ -348,9 +346,12 @@ format.compare_parameters <- function(x,
       # same for correlations
       corrs <- startsWith(out$Parameter[ran_pars_rows], "Cor (")
       # check if we already fixed that name in a previous loop
-      fixed_name <- unlist(lapply(ran_groups, function(g) {
-        which(grepl(g, out$Parameter[ran_pars_rows[corrs]], fixed = TRUE))
-      }))
+      fixed_name <- unlist(lapply(
+        ran_groups,
+        grep,
+        x = out$Parameter[ran_pars_rows[corrs]],
+        fixed = TRUE
+      ))
       if (length(fixed_name)) {
         corrs[fixed_name] <- FALSE
       }
@@ -415,6 +416,13 @@ format.compare_parameters <- function(x,
     formatted_table <- split(out, f = split_by)
     formatted_table <- lapply(names(formatted_table), function(tab) {
       i <- formatted_table[[tab]]
+      # check if data frame is empty - this may happen if not all combinations
+      # of split_by factors are present in the data (e.g., zero-inflated mixed
+      # models, that have random effects for the count, but not for the zero-
+      # inflation component)
+      if (nrow(i) == 0L) {
+        return(NULL)
+      }
       # remove unique columns
       if (insight::n_unique(i$Component) == 1L) i$Component <- NULL
       if (insight::n_unique(i$Effects) == 1L) i$Effects <- NULL
@@ -436,6 +444,9 @@ format.compare_parameters <- function(x,
       i
     })
 
+    # remove empty tables
+    formatted_table <- insight::compact_list(formatted_table)
+
     # for HTML, bind data frames
     if (identical(format, "html")) {
       # fix non-equal length of columns and bind data frames
@@ -460,16 +471,23 @@ format.compare_parameters <- function(x,
 #' @export
 format.parameters_sem <- function(x,
                                   digits = 2,
-                                  ci_digits = 2,
+                                  ci_digits = digits,
                                   p_digits = 3,
                                   format = NULL,
                                   ci_width = NULL,
                                   ci_brackets = TRUE,
                                   pretty_names = TRUE,
                                   ...) {
-  if (missing(digits)) digits <- .additional_arguments(x, "digits", 2)
-  if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", 2)
-  if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
+  if (missing(digits)) {
+    digits <- .additional_arguments(x, "digits", 2)
+  }
+  if (missing(ci_digits)) {
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
+  }
+  if (missing(p_digits)) {
+    p_digits <- .additional_arguments(x, "p_digits", 3)
+  }
+
   .format_columns_multiple_components(
     x,
     pretty_names = TRUE,
@@ -527,7 +545,7 @@ format.parameters_sem <- function(x,
   footer <- NULL
   type <- tolower(format)
 
-  sigma <- attributes(x)$sigma
+  sigma_value <- attributes(x)$sigma
   r2 <- attributes(x)$r2
   residual_df <- attributes(x)$residual_df
   p_adjust <- attributes(x)$p_adjust
@@ -538,6 +556,7 @@ format.parameters_sem <- function(x,
   footer_text <- attributes(x)$footer_text
   text_alternative <- attributes(x)$text_alternative
   n_obs <- attributes(x)$n_obs
+  is_ggeffects <- isTRUE(attributes(x)$is_ggeffects)
 
   # footer: model formula
   if (isTRUE(show_formula)) {
@@ -546,7 +565,7 @@ format.parameters_sem <- function(x,
 
   # footer: residual standard deviation
   if (isTRUE(show_sigma)) {
-    footer <- .add_footer_sigma(footer, digits, sigma, residual_df, type)
+    footer <- .add_footer_sigma(footer, digits, sigma_value, residual_df, type)
   }
 
   # footer: r-squared
@@ -581,7 +600,7 @@ format.parameters_sem <- function(x,
 
   # footer: generic text
   if (!is.null(footer_text)) {
-    footer <- .add_footer_text(footer, footer_text, type)
+    footer <- .add_footer_text(footer, footer_text, type, is_ggeffects)
   }
 
   # add color code, if we have a footer
@@ -594,12 +613,18 @@ format.parameters_sem <- function(x,
     footer[1] <- substr(footer[1], 0, nchar(x) - 1)
   }
 
+  # finally, for ggeffects and HTML, remove *
+  if (is_ggeffects && type == "html") {
+    footer <- gsub("*", "", footer, fixed = TRUE)
+    footer <- gsub(":;", ":", footer, fixed = TRUE)
+  }
+
   footer
 }
 
 
 # footer: generic text
-.add_footer_text <- function(footer = NULL, text, type = "text") {
+.add_footer_text <- function(footer = NULL, text = NULL, type = "text", is_ggeffects = FALSE) {
   if (!is.null(text)) {
     if (type == "text" || type == "markdown") {
       if (is.null(footer)) {
@@ -609,7 +634,8 @@ format.parameters_sem <- function(x,
       }
       footer <- paste0(footer, sprintf("%s%s\n", fill, text))
     } else if (type == "html") {
-      footer <- c(footer, gsub("\n", "", text, fixed = TRUE))
+      replacement <- ifelse(is_ggeffects, ";", "")
+      footer <- c(footer, gsub("\n", replacement, text, fixed = TRUE))
     }
   }
   footer
@@ -617,13 +643,13 @@ format.parameters_sem <- function(x,
 
 
 # footer: residual standard deviation
-.add_footer_sigma <- function(footer = NULL, digits, sigma, residual_df = NULL, type = "text") {
+.add_footer_sigma <- function(footer = NULL, digits = 3, sigma = NULL, residual_df = NULL, type = "text") {
   if (!is.null(sigma)) {
     # format residual df
-    if (!is.null(residual_df)) {
-      res_df <- paste0(" (df = ", residual_df, ")")
-    } else {
+    if (is.null(residual_df)) {
       res_df <- ""
+    } else {
+      res_df <- paste0(" (df = ", residual_df, ")")
     }
 
     if (type == "text" || type == "markdown") {
@@ -642,18 +668,12 @@ format.parameters_sem <- function(x,
 
 
 # footer: r-squared
-.add_footer_r2 <- function(footer = NULL, digits, r2 = NULL, type = "text") {
+.add_footer_r2 <- function(footer = NULL, digits = 3, r2 = NULL, type = "text") {
   if (!is.null(r2)) {
-    rsq <- tryCatch(
-      {
-        paste0(unlist(lapply(r2, function(i) {
-          paste0(attributes(i)$names, ": ", insight::format_value(i, digits = digits))
-        })), collapse = "; ")
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    rsq <- .safe(paste0(unlist(lapply(r2, function(i) {
+      paste0(attributes(i)$names, ": ", insight::format_value(i, digits = digits))
+    })), collapse = "; "))
+
     if (!is.null(rsq)) {
       if (type == "text" || type == "markdown") {
         if (is.null(footer)) {
@@ -672,7 +692,7 @@ format.parameters_sem <- function(x,
 
 
 # footer: anova type
-.add_footer_anova_type <- function(footer = NULL, aov_type, type = "text") {
+.add_footer_anova_type <- function(footer = NULL, aov_type = NULL, type = "text") {
   if (!is.null(aov_type)) {
     if (type == "text" || type == "markdown") {
       if (is.null(footer)) {
@@ -690,7 +710,7 @@ format.parameters_sem <- function(x,
 
 
 # footer: marginaleffects::comparisions() prediction_type
-.add_footer_prediction_type <- function(footer = NULL, prediction_type, type = "text") {
+.add_footer_prediction_type <- function(footer = NULL, prediction_type = NULL, type = "text") {
   if (!is.null(prediction_type)) {
     if (type == "text" || type == "markdown") {
       if (is.null(footer)) {
@@ -708,7 +728,7 @@ format.parameters_sem <- function(x,
 
 
 # footer: anova test
-.add_footer_anova_test <- function(footer = NULL, test, type = "text") {
+.add_footer_anova_test <- function(footer = NULL, test = NULL, type = "text") {
   if (!is.null(test)) {
     if (type == "text" || type == "markdown") {
       if (is.null(footer)) {
@@ -726,7 +746,7 @@ format.parameters_sem <- function(x,
 
 
 # footer: htest alternative
-.add_footer_alternative <- function(footer = NULL, text_alternative, type = "text") {
+.add_footer_alternative <- function(footer = NULL, text_alternative = NULL, type = "text") {
   if (!is.null(text_alternative)) {
     if (type == "text" || type == "markdown") {
       if (is.null(footer)) {
@@ -744,7 +764,7 @@ format.parameters_sem <- function(x,
 
 
 # footer: p-adjustment
-.add_footer_padjust <- function(footer = NULL, p_adjust, type = "text") {
+.add_footer_padjust <- function(footer = NULL, p_adjust = NULL, type = "text") {
   if (!is.null(p_adjust) && p_adjust != "none") {
     if (type == "text" || type == "markdown") {
       if (is.null(footer)) {
@@ -762,13 +782,13 @@ format.parameters_sem <- function(x,
 
 
 # footer: model formula
-.add_footer_formula <- function(footer = NULL, model_formula, n_obs = NULL, type = "text") {
+.add_footer_formula <- function(footer = NULL, model_formula = NULL, n_obs = NULL, type = "text") {
   if (!is.null(model_formula)) {
     # format n of observations
-    if (!is.null(n_obs)) {
-      n <- paste0(" (", n_obs, " Observations)")
-    } else {
+    if (is.null(n_obs)) {
       n <- ""
+    } else {
+      n <- paste0(" (", n_obs, " Observations)")
     }
 
     if (type == "text" || type == "markdown") {
@@ -822,9 +842,9 @@ format.parameters_sem <- function(x,
         }
 
         string_tailed <- switch(ci_method,
-          "hdi" = "highest-density",
-          "uniroot" = ,
-          "profile" = "profile-likelihood",
+          hdi = "highest-density",
+          uniroot = ,
+          profile = "profile-likelihood",
           "equal-tailed"
         )
 
@@ -838,15 +858,15 @@ format.parameters_sem <- function(x,
         }
 
         string_method <- switch(ci_method,
-          "bci" = ,
-          "bcai" = "bias-corrected accelerated bootstrap",
-          "si" = ,
-          "ci" = ,
-          "quantile" = ,
-          "eti" = ,
-          "hdi" = sampling_method,
-          "normal" = "Wald normal",
-          "boot" = "parametric bootstrap",
+          bci = ,
+          bcai = "bias-corrected accelerated bootstrap",
+          si = ,
+          ci = ,
+          quantile = ,
+          eti = ,
+          hdi = sampling_method,
+          normal = "Wald normal",
+          boot = "parametric bootstrap",
           "Wald"
         )
 
@@ -856,11 +876,11 @@ format.parameters_sem <- function(x,
           string_approx <- ""
         }
 
-        if (!is.null(test_statistic) && !ci_method == "normal" && !isTRUE(bootstrap)) {
+        if (!is.null(test_statistic) && ci_method != "normal" && !isTRUE(bootstrap)) {
           string_statistic <- switch(tolower(test_statistic),
-            "t-statistic" = "t",
-            "chi-squared statistic" = ,
-            "z-statistic" = "z",
+            `t-statistic` = "t",
+            `chi-squared statistic` = ,
+            `z-statistic` = "z",
             ""
           )
           string_method <- paste0(string_method, " ", string_statistic, "-")
@@ -872,7 +892,7 @@ format.parameters_sem <- function(x,
         if (isTRUE(bootstrap)) {
           msg <- paste0("\nUncertainty intervals (", string_tailed, ") are ", string_method, "intervals.")
         } else {
-          msg <- paste0("\nUncertainty intervals (", string_tailed, ") and p-values (two-tailed) computed using a ", string_method, "distribution ", string_approx, "approximation.")
+          msg <- paste0("\nUncertainty intervals (", string_tailed, ") and p-values (two-tailed) computed using a ", string_method, "distribution ", string_approx, "approximation.") # nolint
         }
       }
 
@@ -887,7 +907,7 @@ format.parameters_sem <- function(x,
           !ci_method %in% c("wald", "normal", "profile", "boot"))
 
       if (show_re_msg && isTRUE(random_variances) && !is.null(x$Effects) && "random" %in% x$Effects) {
-        msg <- paste(msg, "Uncertainty intervals for random effect variances computed using a Wald z-distribution approximation.")
+        msg <- paste(msg, "Uncertainty intervals for random effect variances computed using a Wald z-distribution approximation.") # nolint
       }
 
       insight::format_alert(msg)
@@ -899,24 +919,50 @@ format.parameters_sem <- function(x,
 .print_footer_exp <- function(x) {
   if (isTRUE(getOption("parameters_exponentiate", TRUE))) {
     msg <- NULL
+    # we need this to check whether we have extremely large cofficients
+    if (all(c("Coefficient", "Parameter") %in% colnames(x))) {
+      spurious_coefficients <- abs(x$Coefficient[!.in_intercepts(x$Parameter)])
+    } else {
+      spurious_coefficients <- NULL
+    }
     exponentiate <- .additional_arguments(x, "exponentiate", FALSE)
     if (!.is_valid_exponentiate_argument(exponentiate)) {
       if (isTRUE(.additional_arguments(x, "log_link", FALSE))) {
-        msg <- "The model has a log- or logit-link. Consider using `exponentiate = TRUE` to interpret coefficients as ratios."
+        msg <- "The model has a log- or logit-link. Consider using `exponentiate = TRUE` to interpret coefficients as ratios." # nolint
+        # we only check for exp(coef), so exp() here soince coefficients are on logit-scale
+        spurious_coefficients <- exp(spurious_coefficients)
       } else if (isTRUE(.additional_arguments(x, "log_response", FALSE))) {
-        msg <- "The model has a log-transformed response variable. Consider using `exponentiate = TRUE` to interpret coefficients as ratios."
+        msg <- "The model has a log-transformed response variable. Consider using `exponentiate = TRUE` to interpret coefficients as ratios." # nolint
+        # don't show warning about complete separation
+        spurious_coefficients <- NULL
       }
-    } else if (.is_valid_exponentiate_argument(exponentiate) && isTRUE(.additional_arguments(x, "log_response", FALSE))) {
+    } else if (.is_valid_exponentiate_argument(exponentiate) && isTRUE(.additional_arguments(x, "log_response", FALSE))) { # nolint
       msg <- c(
         "This model has a log-transformed response variable, and exponentiated parameters are reported.",
-        "A one-unit increase in the predictor is associated with multiplying the outcome by that predictor's coefficient."
+        "A one-unit increase in the predictor is associated with multiplying the outcome by that predictor's coefficient." # nolint
       )
+      # don't show warning about complete separation
+      spurious_coefficients <- NULL
+    }
+
+    # following check only for models with logit-link
+    logit_model <- isTRUE(.additional_arguments(x, "logit_link", FALSE)) ||
+      isTRUE(attributes(x)$coefficient_name %in% c("Log-Odds", "Odds Ratio"))
+
+    # check for complete separation coefficients or possible issues with
+    # too few data points
+    if (!is.null(spurious_coefficients) && logit_model) {
+      if (any(spurious_coefficients > 100)) {
+        msg <- c(msg, "Some coefficients are very large, which may indicate issues with complete separation.") # nolint
+      } else if (any(spurious_coefficients > 25)) {
+        msg <- c(msg, "Some coefficients seem to be rather large, which may indicate issues with (quasi) complete separation. Consider using bias-corrected or penalized regression models.") # nolint
+      }
     }
 
     if (!is.null(msg) && isTRUE(getOption("parameters_warning_exponentiate", TRUE))) {
       insight::format_alert(paste0("\n", msg))
       # set flag, so message only displayed once per session
-      options("parameters_warning_exponentiate" = FALSE)
+      options(parameters_warning_exponentiate = FALSE)
     }
   }
 }
