@@ -26,9 +26,9 @@ p_value.MCMCglmm <- function(model, ...) {
 model_parameters.MCMCglmm <- function(model,
                                       centrality = "median",
                                       dispersion = FALSE,
-                                      ci = .95,
+                                      ci = 0.95,
                                       ci_method = "eti",
-                                      test = c("pd", "rope"),
+                                      test = "pd",
                                       rope_range = "default",
                                       rope_ci = 0.95,
                                       bf_prior = NULL,
@@ -36,7 +36,6 @@ model_parameters.MCMCglmm <- function(model,
                                       priors = TRUE,
                                       keep = NULL,
                                       drop = NULL,
-                                      parameters = keep,
                                       verbose = TRUE,
                                       ...) {
   # Processing
@@ -61,7 +60,7 @@ model_parameters.MCMCglmm <- function(model,
 
   attr(params, "pretty_names") <- format_parameters(model)
   attr(params, "ci") <- ci
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   class(params) <- c("parameters_model", "see_parameters_model", class(params))
 
   params
