@@ -30,10 +30,16 @@ degrees_of_freedom.mipo <- function(model, ...) {
 
 #' @export
 p_value.mipo <- function(model, ...) {
-  .data_frame(
-    Parameter = as.vector(summary(model)$term),
-    p = as.vector(summary(model)$p.value)
+  s <- summary(model)
+  out <- .data_frame(
+    Parameter = as.vector(s$term),
+    p = as.vector(s$p.value)
   )
+  # check for ordinal-alike models
+  if ("y.level" %in% colnames(s)) {
+    out$Response <- as.vector(s$y.level)
+  }
+  out
 }
 
 
@@ -48,10 +54,16 @@ p_value.mira <- function(model, ...) {
 
 #' @export
 standard_error.mipo <- function(model, ...) {
-  .data_frame(
-    Parameter = as.vector(summary(model)$term),
-    SE = as.vector(summary(model)$std.error)
+  s <- summary(model)
+  out <- .data_frame(
+    Parameter = as.vector(s$term),
+    SE = as.vector(s$std.error)
   )
+  # check for ordinal-alike models
+  if ("y.level" %in% colnames(s)) {
+    out$Response <- as.vector(s$y.level)
+  }
+  out
 }
 
 
@@ -72,14 +84,55 @@ format_parameters.mira <- format_parameters.rma
 
 #' @rdname model_parameters.mira
 #' @export
-model_parameters.mipo <- model_parameters.default
+model_parameters.mipo <- function(model,
+                                  ci = 0.95,
+                                  exponentiate = FALSE,
+                                  p_adjust = NULL,
+                                  keep = NULL,
+                                  drop = NULL,
+                                  verbose = TRUE,
+                                  ...) {
+  # validation check, warn if unsupported argument is used.
+  dot_args <- .check_dots(
+    dots = list(...),
+    not_allowed = c("vcov", "vcov_args"),
+    class(model)[1],
+    verbose = verbose
+  )
+
+  # check if we have ordinal/categorical response
+  s <- summary(model)
+  if ("y.level" %in% colnames(s)) {
+    merge_by <- c("Parameter", "Response")
+  } else {
+    merge_by <- "Parameter"
+  }
+
+  fun_args <- list(
+    model,
+    ci = ci,
+    merge_by = merge_by,
+    exponentiate = exponentiate,
+    p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    vcov = NULL,
+    vcov_args = NULL
+  )
+  fun_args <- c(fun_args, dot_args)
+
+  out <- do.call(".model_parameters_generic", fun_args)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
+  out
+}
 
 
 #' Parameters from multiply imputed repeated analyses
 #'
-#' Format models of class `mira`, obtained from `mice::width.mids()`.
+#' Format models of class `mira`, obtained from `mice::width.mids()`, or of
+#' class `mipo`.
 #'
-#' @param model An object of class `mira`.
+#' @param model An object of class `mira` or `mipo`.
 #' @inheritParams model_parameters.default
 #' @param ... Arguments passed to or from other methods.
 #'
@@ -95,7 +148,7 @@ model_parameters.mipo <- model_parameters.default
 #'   fit <- with(data = imp, exp = lm(bmi ~ age + hyp + chl))
 #'   model_parameters(fit)
 #' }
-#' \dontrun{
+#' \donttest{
 #' # model_parameters() also works for models that have no "tidy"-method in mice
 #' if (require("mice", quietly = TRUE) && require("gee", quietly = TRUE)) {
 #'   data(warpbreaks)
@@ -127,12 +180,15 @@ model_parameters.mira <- function(model,
                                   ci = 0.95,
                                   exponentiate = FALSE,
                                   p_adjust = NULL,
+                                  keep = NULL,
+                                  drop = NULL,
                                   verbose = TRUE,
                                   ...) {
   insight::check_if_installed("mice")
+  micemodel <- suppressWarnings(mice::pool(model))
 
   out <- .model_parameters_generic(
-    model = mice::pool(model),
+    model = micemodel,
     ci = ci,
     bootstrap = FALSE,
     iterations = 10,
@@ -140,6 +196,9 @@ model_parameters.mira <- function(model,
     standardize = NULL,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    verbose = verbose,
     ...
   )
 
