@@ -20,18 +20,15 @@
 #' @seealso [insight::standardize_names()] to rename
 #'   columns into a consistent, standardized naming scheme.
 #'
-#' @examples
-#' library(parameters)
-#' if (require("brglm2", quietly = TRUE)) {
-#'   data("stemcell")
-#'   model <- bracl(
-#'     research ~ as.numeric(religion) + gender,
-#'     weights = frequency,
-#'     data = stemcell,
-#'     type = "ML"
-#'   )
-#'   model_parameters(model)
-#' }
+#' @examplesIf require("brglm2", quietly = TRUE)
+#' data("stemcell", package = "brglm2")
+#' model <- brglm2::bracl(
+#'   research ~ as.numeric(religion) + gender,
+#'   weights = frequency,
+#'   data = stemcell,
+#'   type = "ML"
+#' )
+#' model_parameters(model)
 #' @return A data frame of indices related to the model's parameters.
 #' @inheritParams simulate_model
 #' @export
@@ -44,6 +41,8 @@ model_parameters.mlm <- function(model,
                                  standardize = NULL,
                                  exponentiate = FALSE,
                                  p_adjust = NULL,
+                                 keep = NULL,
+                                 drop = NULL,
                                  verbose = TRUE,
                                  ...) {
   out <- .model_parameters_generic(
@@ -57,6 +56,8 @@ model_parameters.mlm <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
     ...
   )
   attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
@@ -76,13 +77,12 @@ standard_error.mlm <- function(model,
     se$Parameter <- est$Parameter
     se$Response <- est$Response
     return(se)
-
-    # manually
   } else {
+    # manually
     if (!is.null(vcov)) {
-      warning(insight::format_message(
+      insight::format_warning(
         "Unable to extract the variance-covariance matrix requested in `vcov`."
-      ))
+      )
     }
     cs <- stats::coef(summary(model))
     se <- lapply(names(cs), function(x) {
@@ -111,9 +111,9 @@ p_value.mlm <- function(model, vcov = NULL, vcov_args = NULL, ...) {
     # manually
   } else {
     if (!is.null(vcov)) {
-      warning(insight::format_message(
+      insight::format_warning(
         "Unable to extract the variance-covariance matrix requested in `vcov`."
-      ))
+      )
     }
     cs <- stats::coef(summary(model))
     p <- lapply(names(cs), function(x) {
@@ -164,16 +164,14 @@ ci.mlm <- function(x,
     )
 
     resp <- insight::get_parameters(x)$Response
-    if (!"Reponse" %in% colnames(out) && nrow(out) == length(resp)) {
+    if (!"Response" %in% colnames(out) && nrow(out) == length(resp)) {
       out[["Response"]] <- resp
-    } else {
-      if (!isTRUE(all(out$Response == resp))) {
-        insight::format_error(
-          "Unable to assign labels to the model's parameters.",
-          "Please report this problem to the {.pkg parameters} issue tracker:",
-          "{.url https://github.com/easystats/parameters/issues}"
-        )
-      }
+    } else if (!isTRUE(all(out$Response == resp))) {
+      insight::format_error(
+        "Unable to assign labels to the model's parameters.",
+        "Please report this problem to the {.pkg parameters} issue tracker:",
+        "{.url https://github.com/easystats/parameters/issues}"
+      )
     }
   }
   out
@@ -202,10 +200,10 @@ simulate_parameters.mlm <- function(model,
                                     ci_method = "quantile",
                                     test = "p-value",
                                     ...) {
-  data <- simulate_model(model, iterations = iterations, ...)
+  sim_data <- simulate_model(model, iterations = iterations, ...)
   out <-
     .summary_bootstrap(
-      data = data,
+      data = sim_data,
       test = test,
       centrality = centrality,
       ci = ci,
