@@ -13,18 +13,18 @@ standard_error.complmrob <- function(model, ...) {
 
 
 #' @export
-p_value.complmrob <- function(model, ...) {
-  stats <- summary(model)$stats
-  params <- insight::get_parameters(model)
-  .data_frame(
-    Parameter = params$Parameter,
-    p = as.vector(stats[, "Pr(>|t|)"])
-  )
-}
+p_value.complmrob <- p_value.default
 
 
 #' @export
-ci.comlmrob <- ci.default
+ci.complmrob <- ci.default
+
+
+#' @export
+degrees_of_freedom.complmrob <- function(model, method = "wald", ...) {
+  .degrees_of_freedom_no_dfresid_method(model, method)
+}
+
 
 
 
@@ -32,22 +32,23 @@ ci.comlmrob <- ci.default
 ############# .Gam --------------
 
 
+#' @rdname model_parameters.cgam
+#' @inheritParams model_parameters.aov
 #' @export
 model_parameters.Gam <- function(model,
-                                 omega_squared = NULL,
-                                 eta_squared = NULL,
-                                 epsilon_squared = NULL,
+                                 effectsize_type = NULL,
                                  df_error = NULL,
                                  type = NULL,
+                                 table_wide = FALSE,
                                  verbose = TRUE,
                                  ...) {
   model_parameters(
     summary(model)$parametric.anova,
-    omega_squared = omega_squared,
-    eta_squared = eta_squared,
-    epsilon_squared = epsilon_squared,
+    effectsize_type = effectsize_type,
     df_error = df_error,
     type = type,
+    table_wide = table_wide,
+    verbose = verbose,
     ...
   )
 }
