@@ -7,13 +7,14 @@
 #' Details section).
 #'
 #' @param x A data frame or a statistical model.
-#' @param n Number of components to extract. If `n="all"`, then `n` is
-#'   set as the number of variables minus 1 (`ncol(x)-1`). If
-#'   `n="auto"` (default) or `n=NULL`, the number of components is
-#'   selected through [`n_factors()`] resp. [`n_components()`].
-#'   In [`reduce_parameters()`], can also be `"max"`, in which case
-#'   it will select all the components that are maximally pseudo-loaded (i.e.,
-#'   correlated) by at least one variable.
+#' @param n Number of components to extract. If `n="all"`, then `n` is set as
+#'   the number of variables minus 1 (`ncol(x)-1`). If `n="auto"` (default) or
+#'   `n=NULL`, the number of components is selected through [`n_factors()`] resp.
+#'   [`n_components()`]. Else, if `n` is a number, `n` components are extracted.
+#'   If `n` exceeds number of variables in the data, it is automatically set to
+#'   the maximum number (i.e. `ncol(x)`). In [`reduce_parameters()`], can also
+#'   be `"max"`, in which case it will select all the components that are
+#'   maximally pseudo-loaded (i.e., correlated) by at least one variable.
 #' @param rotation If not `"none"`, the PCA / FA will be computed using the
 #'   **psych** package. Possible options include `"varimax"`,
 #'   `"quartimax"`, `"promax"`, `"oblimin"`, `"simplimax"`,
@@ -167,7 +168,7 @@
 #'
 #' efa <- factor_analysis(mtcars[, 1:5], n = 2)
 #' summary(efa)
-#' predict(efa)
+#' predict(efa, verbose = FALSE)
 #'
 #' \donttest{
 #' # Automated number of components
@@ -208,7 +209,7 @@ principal_components <- function(x,
 
 #' @rdname principal_components
 #' @export
-rotated_data <- function(pca_results) {
+rotated_data <- function(pca_results, verbose = TRUE) {
   original_data <- attributes(pca_results)$dataset
   rotated_matrix <- insight::get_predicted(attributes(pca_results)$model)
   out <- NULL
@@ -216,7 +217,9 @@ rotated_data <- function(pca_results) {
   if (!is.null(original_data) && !is.null(rotated_matrix)) {
     compl_cases <- attributes(pca_results)$complete_cases
     if (is.null(compl_cases) && nrow(original_data) != nrow(rotated_matrix)) {
-      insight::format_warning("Could not retrieve information about missing data.")
+      if (verbose) {
+        insight::format_warning("Could not retrieve information about missing data.")
+      }
       return(NULL)
     }
     original_data$.parameters_merge_id <- seq_len(nrow(original_data))
@@ -224,7 +227,9 @@ rotated_data <- function(pca_results) {
     out <- merge(original_data, rotated_matrix, by = ".parameters_merge_id", all = TRUE, sort = FALSE)
     out$.parameters_merge_id <- NULL
   } else {
-    insight::format_warning("Either the original or the rotated data could not be retrieved.")
+    if (verbose) {
+      insight::format_warning("Either the original or the rotated data could not be retrieved.")
+    }
     return(NULL)
   }
   out
@@ -414,7 +419,9 @@ principal_components.data.frame <- function(x,
   } else if (n == "all") {
     n <- ncol(x) - 1
   } else if (n >= ncol(x)) {
-    n <- ncol(x) - 1
+    n <- ncol(x)
+  } else if (n < 1) {
+    n <- 1
   }
   n
 }
