@@ -87,6 +87,11 @@
 #'   labels will be used as parameters names. The latter only works for "labelled"
 #'   data, i.e. if the data used to fit the model had `"label"` and `"labels"`
 #'   attributes. See also section _Global Options to Customize Messages when Printing_.
+#' @param include_reference Logical, if `TRUE`, the reference level of factors will
+#'   be added to the parameters table. This is only relevant for models with
+#'   categorical predictors. The coefficient for the reference level is always
+#'   `0` (except when `exponentiate = TRUE`, then the coefficient will be `1`),
+#'   so this is just for completeness.
 #' @inheritParams insight::format_table
 #' @inheritParams compare_parameters
 #'
@@ -141,26 +146,24 @@
 #'   [`print_md()`][print_md.parameters_model]. See also
 #'   [`display()`][display.parameters_model].
 #'
-#' @examples
+#' @examplesIf require("gt", quietly = TRUE) && require("glmmTMB", quietly = TRUE)
 #' \donttest{
 #' library(parameters)
-#' if (require("glmmTMB", quietly = TRUE)) {
-#'   model <- glmmTMB(
-#'     count ~ spp + mined + (1 | site),
-#'     ziformula = ~mined,
-#'     family = poisson(),
-#'     data = Salamanders
-#'   )
-#'   mp <- model_parameters(model)
+#' model <- glmmTMB::glmmTMB(
+#'   count ~ spp + mined + (1 | site),
+#'   ziformula = ~mined,
+#'   family = poisson(),
+#'   data = Salamanders
+#' )
+#' mp <- model_parameters(model)
 #'
-#'   print(mp, pretty_names = FALSE)
+#' print(mp, pretty_names = FALSE)
 #'
-#'   print(mp, split_components = FALSE)
+#' print(mp, split_components = FALSE)
 #'
-#'   print(mp, select = c("Parameter", "Coefficient", "SE"))
+#' print(mp, select = c("Parameter", "Coefficient", "SE"))
 #'
-#'   print(mp, select = "minimal")
-#' }
+#' print(mp, select = "minimal")
 #'
 #'
 #' # group parameters ------
@@ -211,7 +214,7 @@
 #' result <- compare_parameters(lm1, lm2, select = "{estimate}{stars} ({se})")
 #' print(result)
 #'
-#' \dontrun{
+#' \donttest{
 #' # custom style, in HTML
 #' result <- compare_parameters(lm1, lm2, select = "{estimate}<br>({se})|{p}")
 #' print_html(result)
@@ -224,7 +227,7 @@ print.parameters_model <- function(x,
                                    caption = NULL,
                                    footer = NULL,
                                    digits = 2,
-                                   ci_digits = 2,
+                                   ci_digits = digits,
                                    p_digits = 3,
                                    footer_digits = 3,
                                    show_sigma = FALSE,
@@ -233,6 +236,7 @@ print.parameters_model <- function(x,
                                    groups = NULL,
                                    column_width = NULL,
                                    ci_brackets = c("[", "]"),
+                                   include_reference = FALSE,
                                    ...) {
   # save original input
   orig_x <- x
@@ -256,7 +260,7 @@ print.parameters_model <- function(x,
     digits <- .additional_arguments(x, "digits", digits)
   }
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
   if (missing(p_digits)) {
     p_digits <- .additional_arguments(x, "p_digits", p_digits)
@@ -282,6 +286,7 @@ print.parameters_model <- function(x,
     ci_brackets = ci_brackets,
     format = "text",
     groups = groups,
+    include_reference = include_reference,
     ...
   )
 
@@ -371,13 +376,14 @@ print.parameters_random <- function(x, digits = 2, ...) {
                         split_components = TRUE,
                         select = NULL,
                         digits = 2,
-                        ci_digits = 2,
+                        ci_digits = digits,
                         p_digits = 3,
                         zap_small = FALSE,
                         ci_width = "auto",
                         ci_brackets = TRUE,
                         format = "text",
                         group = NULL,
+                        include_reference = FALSE,
                         ...) {
   format(
     x,
@@ -392,6 +398,7 @@ print.parameters_random <- function(x, digits = 2, ...) {
     zap_small = zap_small,
     format = format,
     group = group,
+    include_reference = include_reference,
     ...
   )
 }
