@@ -11,7 +11,7 @@ print_md.parameters_model <- function(x,
                                       footer = NULL,
                                       align = NULL,
                                       digits = 2,
-                                      ci_digits = 2,
+                                      ci_digits = digits,
                                       p_digits = 3,
                                       footer_digits = 3,
                                       ci_brackets = c("(", ")"),
@@ -19,6 +19,7 @@ print_md.parameters_model <- function(x,
                                       show_formula = FALSE,
                                       zap_small = FALSE,
                                       groups = NULL,
+                                      include_reference = FALSE,
                                       verbose = TRUE,
                                       ...) {
   # check if user supplied digits attributes
@@ -26,7 +27,7 @@ print_md.parameters_model <- function(x,
     digits <- .additional_arguments(x, "digits", digits)
   }
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
   if (missing(p_digits)) {
     p_digits <- .additional_arguments(x, "p_digits", p_digits)
@@ -66,6 +67,7 @@ print_md.parameters_model <- function(x,
     ci_brackets = ci_brackets,
     format = "markdown",
     groups = groups,
+    include_reference = include_reference,
     ...
   )
 
@@ -124,20 +126,23 @@ print_md.parameters_simulate <- print_md.parameters_model
 #' @export
 print_md.compare_parameters <- function(x,
                                         digits = 2,
-                                        ci_digits = 2,
+                                        ci_digits = digits,
                                         p_digits = 3,
                                         caption = NULL,
                                         subtitle = NULL,
                                         footer = NULL,
                                         select = NULL,
                                         split_components = TRUE,
+                                        ci_brackets = c("(", ")"),
+                                        zap_small = FALSE,
+                                        groups = NULL,
                                         ...) {
   # check if user supplied digits attributes
   if (missing(digits)) {
     digits <- .additional_arguments(x, "digits", digits)
   }
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
   if (missing(p_digits)) {
     p_digits <- .additional_arguments(x, "p_digits", p_digits)
@@ -156,8 +161,10 @@ print_md.compare_parameters <- function(x,
     ci_digits = ci_digits,
     p_digits = p_digits,
     ci_width = NULL,
-    ci_brackets = c("(", ")"),
-    format = "markdown"
+    ci_brackets = ci_brackets,
+    format = "markdown",
+    zap_small = zap_small,
+    groups = groups
   )
 
   insight::export_table(
@@ -178,7 +185,7 @@ print_md.compare_parameters <- function(x,
 #' @export
 print_md.parameters_sem <- function(x,
                                     digits = 2,
-                                    ci_digits = 2,
+                                    ci_digits = digits,
                                     p_digits = 3,
                                     ci_brackets = c("(", ")"),
                                     ...) {
@@ -188,7 +195,7 @@ print_md.parameters_sem <- function(x,
     digits <- .additional_arguments(x, "digits", digits)
   }
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
   if (missing(p_digits)) {
     p_digits <- .additional_arguments(x, "p_digits", p_digits)
@@ -320,13 +327,3 @@ print_md.parameters_distribution <- function(x, digits = 2, ci_brackets = c("(",
 
   insight::export_table(formatted_table, format = "markdown", align = "firstleft", ...)
 }
-
-
-
-
-
-# Reexports models ------------------------
-
-#' @importFrom insight print_md
-#' @export
-insight::print_md
