@@ -13,32 +13,28 @@
 
   pattern <- if (full) {
     c(
-      "as.factor", "as.numeric", "factor", "offset", "lag", "diff", "catg",
-      "asis", "matrx", "pol", "strata", "strat", "scale", "scored",
-      "interaction", "lsp", "pb", "lo", "t2", "te", "ti", "tt",
-      "mi", "mo", "gp"
+      "as.factor", "as.numeric", "as.ordered", "factor", "ordered", "offset",
+      "lag", "diff", "catg", "matrx", "pol", "strata", "strat", "scale",
+      "scored", "interaction", "lsp", "pb", "lo", "t2", "te", "ti", "tt", "mi",
+      "mo", "gp"
     )
   } else {
-    c("as.factor", "as.numeric", "factor", "catg", "asis", "interaction")
+    c("as.factor", "as.numeric", "as.ordered", "factor", "ordered", "catg", "interaction")
   }
 
-  for (j in 1:length(pattern)) {
+  for (j in seq_along(pattern)) {
     # remove possible  namespace
-    x <- sub("(.*)::(.*)", "\\2", x)
-    if (pattern[j] == "offset") {
-      x <- trimws(sub("offset\\(([^-+ )]*)\\)(.*)", "\\1\\2", x))
-    } else if (pattern[j] == "I") {
-      if (full) {
-        x <- trimws(sub("I\\(((\\w|\\.)*).*", "\\1", x))
-      } else {
-        x <- trimws(sub("I\\((.*)\\)(.*)", "\\1", x))
-      }
+    if (any(grepl("::", x, fixed = TRUE))) {
+      x <- sub("(.*)::(.*)", "\\2", x)
+    }
+    if (pattern[j] == "offset" && any(grepl("offset(", x, fixed = TRUE))) {
+      x <- insight::trim_ws(sub("offset\\(([^-+ )]*)\\)(.*)", "\\1\\2", x))
       # some exceptions here...
-    } else if (full && pattern[j] == "scale" && any(grepl("scale\\(", x))) {
-      x[grepl("scale\\(", x)] <- insight::clean_names(x[grepl("scale\\(", x)])
-    } else {
+    } else if (full && pattern[j] == "scale" && any(grepl("scale(", x, fixed = TRUE))) {
+      x[grepl("scale(", x, fixed = TRUE)] <- insight::clean_names(grep("scale(", x, fixed = TRUE, value = TRUE))
+    } else if (any(grepl(pattern[j], x, fixed = TRUE))) {
       p <- paste0(pattern[j], "\\(((\\w|\\.)*)\\)(.*)")
-      x <- trimws(sub(p, "\\1\\3", x))
+      x <- insight::trim_ws(sub(p, "\\1\\3", x))
     }
   }
 
@@ -56,19 +52,12 @@
   x
 }
 
-#' @keywords internal
-.remove_backticks_from_parameter_names <- function(x) {
-  if (is.data.frame(x) && "Parameter" %in% colnames(x)) {
-    x$Parameter <- gsub("`", "", x$Parameter, fixed = TRUE)
-  }
-  x
-}
-
 #' @keywords internal
 .intercepts <- function() {
   c(
     "(intercept)_zi",
     "intercept (zero-inflated)",
+    "intercept (zero-inflation)",
     "intercept",
     "zi_intercept",
     "(intercept)",
@@ -79,5 +68,5 @@
 
 #' @keywords internal
 .in_intercepts <- function(x) {
-  tolower(x) %in% .intercepts() | grepl("^intercept", tolower(x))
+  tolower(x) %in% .intercepts() | startsWith(tolower(x), "intercept")
 }
