@@ -19,9 +19,7 @@
   dot.arguments <- list(...)
 
   # model info
-  info <- tryCatch(suppressWarnings(insight::model_info(model, verbose = FALSE)),
-    error = function(e) NULL
-  )
+  info <- .safe(suppressWarnings(insight::model_info(model, verbose = FALSE)))
 
   if (is.null(info)) {
     info <- list(family = "unknown", link_function = "unknown")
@@ -29,7 +27,7 @@
 
   # for simplicity, we just use the model information from the first formula
   # when we have multivariate response models...
-  if (insight::is_multivariate(model) && !"is_zero_inflated" %in% names(info)) {
+  if (insight::is_multivariate(model) && !"is_zero_inflated" %in% names(info) && !inherits(model, c("vgam", "vglm"))) {
     info <- info[[1]]
   }
 
@@ -58,14 +56,18 @@
   attr(params, "ran_pars") <- isFALSE(group_level)
   attr(params, "show_summary") <- isTRUE(summary)
   attr(params, "log_link") <- isTRUE(grepl("log", info$link_function, fixed = TRUE))
+  attr(params, "logit_link") <- isTRUE(identical(info$link_function, "logit"))
 
   # add parameters with value and variable
   attr(params, "pretty_labels") <- .format_value_labels(params, model)
 
+  # save model call
+  attr(params, "model_call") <- .safe(insight::get_call(model))
+
   # use tryCatch, these might fail...
-  attr(params, "test_statistic") <- tryCatch(insight::find_statistic(model), error = function(e) NULL)
-  attr(params, "log_response") <- tryCatch(isTRUE(grepl("log", insight::find_transformation(model), fixed = TRUE)), error = function(e) NULL)
-  attr(params, "log_predictors") <- tryCatch(any(grepl("log", unlist(insight::find_terms(model)[c("conditional", "zero_inflated", "instruments")]), fixed = TRUE)), error = function(e) NULL)
+  attr(params, "test_statistic") <- .safe(insight::find_statistic(model))
+  attr(params, "log_response") <- .safe(isTRUE(grepl("log", insight::find_transformation(model), fixed = TRUE)))
+  attr(params, "log_predictors") <- .safe(any(grepl("log", unlist(insight::find_terms(model)[c("conditional", "zero_inflated", "instruments")]), fixed = TRUE))) # nolint
 
   # save if model is multivariate response model
   if (isTRUE(info$is_multivariate)) {
@@ -80,7 +82,7 @@
 
   # for summaries, add R2
   if (isTRUE(summary) && requireNamespace("performance", quietly = TRUE)) {
-    rsq <- tryCatch(suppressWarnings(performance::r2(model)), error = function(e) NULL)
+    rsq <- .safe(suppressWarnings(performance::r2(model)))
     attr(params, "r2") <- rsq
   }
 
@@ -88,30 +90,25 @@
   # Models for which titles should be removed - here we add exceptions for
   # objects that should not have a table headline like "# Fixed Effects", when
   # there is nothing else than fixed effects (redundant title)
-  if (inherits(model, c("mediate", "emmGrid", "emm_list", "summary_emm", "lm",
-                        "glm", "coxph", "bfsl", "deltaMethod"))) {
+  if (inherits(model, c(
+    "mediate", "emmGrid", "emm_list", "summary_emm", "lm", "averaging",
+    "glm", "coxph", "bfsl", "deltaMethod", "phylolm", "phyloglm"
+  ))) {
     attr(params, "no_caption") <- TRUE
     attr(params, "title") <- ""
   }
 
 
   # weighted nobs
-  weighted_nobs <- tryCatch(
-    {
-      w <- insight::get_weights(model, na_rm = TRUE, null_as_ones = TRUE)
-      round(sum(w))
-    },
-    error = function(e) {
-      NULL
-    }
-  )
+  weighted_nobs <- .safe({
+    w <- insight::get_weights(model, na_rm = TRUE, null_as_ones = TRUE)
+    round(sum(w))
+  })
   attr(params, "weighted_nobs") <- weighted_nobs
 
 
   # model formula
-  model_formula <- tryCatch(insight::safe_deparse(insight::find_formula(model)$conditional),
-    error = function(e) NULL
-  )
+  model_formula <- .safe(insight::safe_deparse(insight::find_formula(model)$conditional))
   attr(params, "model_formula") <- model_formula
 
 
@@ -137,9 +134,7 @@
   # special handling for meta analysis. we need additional
   # information about study weights
   if (inherits(model, c("rma", "rma.uni"))) {
-    rma_data <- tryCatch(insight::get_data(model, verbose = FALSE),
-      error = function(e) NULL
-    )
+    rma_data <- .safe(insight::get_data(model, verbose = FALSE))
     attr(params, "data") <- rma_data
     attr(params, "study_weights") <- 1 / model$vi
   }
@@ -148,9 +143,7 @@
   # special handling for meta analysis again, but these objects save the
   # inverse weighting information in a different column.
   if (inherits(model, c("meta_random", "meta_fixed", "meta_bma"))) {
-    rma_data <- tryCatch(insight::get_data(model, verbose = FALSE),
-      error = function(e) NULL
-    )
+    rma_data <- .safe(insight::get_data(model, verbose = FALSE))
     attr(params, "data") <- rma_data
     attr(params, "study_weights") <- 1 / params$SE^2
   }
@@ -170,7 +163,7 @@
   if ("ci_digits" %in% names(dot.arguments)) {
     attr(params, "ci_digits") <- dot.arguments[["ci_digits"]]
   } else {
-    attr(params, "ci_digits") <- 2
+    attr(params, "ci_digits") <- NULL
   }
 
   if ("p_digits" %in% names(dot.arguments)) {
@@ -224,16 +217,16 @@
 
   switch(tolower(ci_method),
     # abbreviations
-    "eti" = ,
-    "hdi" = ,
-    "si" = toupper(ci_method),
+    eti = ,
+    hdi = ,
+    si = toupper(ci_method),
     # named after people
-    "satterthwaite" = ,
-    "kenward" = ,
-    "wald" = insight::format_capitalize(ci_method),
+    satterthwaite = ,
+    kenward = ,
+    wald = insight::format_capitalize(ci_method),
     # special cases
-    "bci" = ,
-    "bcai" = "BCa",
+    bci = ,
+    bcai = "BCa",
     # no change otherwise
     ci_method
   )
@@ -247,35 +240,41 @@
     name <- attributes(s)$estName
     if (!is.null(name)) {
       coef_col <- switch(name,
-        "prob"       = "Probability",
-        "odds.ratio" = "Odds Ratio",
-        "emmean"     = "Marginal Means",
-        "rate"       = "Estimated Counts",
-        "ratio"      = "Ratio",
+        prob       = "Probability",
+        odds.ratio = "Odds Ratio",
+        emmean     = "Marginal Means",
+        rate       = "Estimated Counts",
+        ratio      = "Ratio",
         "Coefficient"
       )
     }
-  } else if (!is.null(info) && !info$family == "unknown") {
+  } else if (!is.null(info) && info$family != "unknown") {
     if (isTRUE(exponentiate)) {
       if (info$is_exponential && identical(info$link_function, "log")) {
         coef_col <- "Prevalence Ratio"
       } else if ((info$is_binomial && info$is_logit) || info$is_ordinal || info$is_multinomial || info$is_categorical) {
         coef_col <- "Odds Ratio"
       } else if (info$is_binomial && !info$is_logit) {
-        coef_col <- "Risk Ratio"
+        if (info$link_function == "identity") {
+          coef_col <- "Exp. Risk"
+        } else {
+          coef_col <- "Risk Ratio"
+        }
       } else if (info$is_count) {
         coef_col <- "IRR"
       }
-    } else {
-      if (info$is_exponential && identical(info$link_function, "log")) {
-        coef_col <- "Log-Prevalence"
-      } else if ((info$is_binomial && info$is_logit) || info$is_ordinal || info$is_multinomial || info$is_categorical) {
-        coef_col <- "Log-Odds"
-      } else if (info$is_binomial && !info$is_logit) {
+    } else if (info$is_exponential && identical(info$link_function, "log")) {
+      coef_col <- "Log-Prevalence"
+    } else if ((info$is_binomial && info$is_logit) || info$is_ordinal || info$is_multinomial || info$is_categorical) {
+      coef_col <- "Log-Odds"
+    } else if (info$is_binomial && !info$is_logit) {
+      if (info$link_function == "identity") {
+        coef_col <- "Risk"
+      } else {
         coef_col <- "Log-Risk"
-      } else if (info$is_count) {
-        coef_col <- "Log-Mean"
       }
+    } else if (info$is_count) {
+      coef_col <- "Log-Mean"
     }
   }
 
@@ -303,17 +302,28 @@
     return(params)
   }
 
-  columns <- grepl(pattern = "^(Coefficient|Mean|Median|MAP|Std_Coefficient|CI_|Std_CI)", colnames(params))
+  # pattern for marginaleffects objects
+  if (is.null(attr(params, "coefficient_name"))) {
+    pattern <- "^(Coefficient|Mean|Median|MAP|Std_Coefficient|CI_|Std_CI)"
+  } else {
+    pattern <- sprintf(
+      "^(Coefficient|Mean|Median|MAP|Std_Coefficient|%s|CI_|Std_CI)",
+      attr(params, "coefficient_name")
+    )
+  }
+
+  columns <- grepl(pattern = pattern, colnames(params))
   if (any(columns)) {
     if (inherits(model, "mvord")) {
       rows <- params$Component != "correlation"
-    } else {
+    } else if (inherits(model, c("clm", "clm2", "clmm"))) {
+      ## TODO: make sure we catch all ordinal models properly here
+      rows <- !tolower(params$Component) %in% c("location", "scale")
+    } else if (is.null(params$Component)) {
       # don't exponentiate dispersion
-      if (!is.null(params$Component)) {
-        rows <- !tolower(params$Component) %in% c("dispersion", "residual")
-      } else {
-        rows <- seq_len(nrow(params))
-      }
+      rows <- seq_len(nrow(params))
+    } else {
+      rows <- !tolower(params$Component) %in% c("dispersion", "residual")
     }
     params[rows, columns] <- exp(params[rows, columns])
     if (all(c("Coefficient", "SE") %in% names(params))) {
@@ -337,10 +347,8 @@
   )
 
   # add Group variable
-  if (!is.null(clean_params$Group) && any(nchar(clean_params$Group) > 0)) {
-    params$Group <- tryCatch(gsub("(.*): (.*)", "\\2", clean_params$Group),
-      error = function(e) NULL
-    )
+  if (!is.null(clean_params$Group) && any(nzchar(clean_params$Group, keepNA = TRUE))) {
+    params$Group <- .safe(gsub("(.*): (.*)", "\\2", clean_params$Group))
   }
 
   attr(params, "cleaned_parameters") <- named_clean_params
@@ -354,7 +362,7 @@
 
 #' @keywords internal
 .add_anova_attributes <- function(params, model, ci, test = NULL, alternative = NULL, ...) {
-  dot.arguments <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
+  dot.arguments <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x) # nolint
 
   attr(params, "ci") <- ci
   attr(params, "model_class") <- class(model)
@@ -386,7 +394,7 @@
   if ("ci_digits" %in% names(dot.arguments)) {
     attr(params, "ci_digits") <- eval(dot.arguments[["ci_digits"]])
   } else {
-    attr(params, "ci_digits") <- 2
+    attr(params, "ci_digits") <- NULL
   }
 
   if ("p_digits" %in% names(dot.arguments)) {
@@ -405,10 +413,10 @@
 
 
 .additional_arguments <- function(x, value, default) {
-  args <- attributes(x)$additional_arguments
+  add_args <- attributes(x)$additional_arguments
 
-  if (length(args) > 0 && value %in% names(args)) {
-    out <- args[[value]]
+  if (length(add_args) > 0 && value %in% names(add_args)) {
+    out <- add_args[[value]]
   } else {
     out <- attributes(x)[[value]]
   }
@@ -439,9 +447,9 @@
   if (length(not_allowed)) {
     if (verbose) {
       not_allowed_string <- datawizard::text_concatenate(not_allowed, enclose = "\"")
-      insight::format_warning(
-        sprintf("Following arguments are not supported in `%s()` for models of class `%s` and will be ignored: %s", function_name, model_class, not_allowed_string),
-        sprintf("Please run `%s()` again without specifying the above mentioned arguments to obtain expected results.", function_name)
+      insight::format_alert(
+        sprintf("Following arguments are not supported in `%s()` for models of class `%s` and will be ignored: %s", function_name, model_class, not_allowed_string), # nolint
+        sprintf("Please run `%s()` again without specifying the above mentioned arguments to obtain expected results.", function_name) # nolint
       )
     }
     dots[not_allowed] <- NULL
